#!/bin/sh

mtd_file=/proc/mtd
ubi_device_number=1

FindAndAttachUBI() {
   partition=$1

   mtd_block_number=`cat $mtd_file | grep -i $partition | sed 's/^mtd//' | awk -F ':' '{print $1}'`
   if [ -z "$mtd_block_number" ]; then
      echo "MTD : Partition $partition not found"
   else
      echo "MTD : Attaching UBI device /dev/mtdblock$mtd_block_number for $partition @$ubi_device_number"

      ubiattach -m $mtd_block_number
      while [ 1 ]; do
         if [ -c /dev/ubi$ubi_device_number ]; then
            break
         else
            sleep 0.010
         fi
      done
      ubi_device_number=$(($ubi_device_number + 1))
   fi
}

FindAndDetachUBI() (
   partition=$1

   mtd_block_number=`cat $mtd_file | grep -i $partition | sed 's/^mtd//' | awk -F ':' '{print $1}'`
   if [ -z "$mtd_block_number" ]; then
      echo "MTD : Partition $partition not found"
   else
      echo "MTD : Detaching UBI device /dev/mtdblock$mtd_block_number for $partition @$ubi_device_number"

      ubidetach -m $mtd_block_number
   fi
)

FindAndMountUBI () {
   volume=$1
   dir=$2

   echo "MTD : Looking for UBI volume : $dir for $volume"
   mkdir -p $dir

   # Skip ubi0 for recoveryfs
   for ubidev in /dev/ubi[1-99]_*; do
      volname=`ubinfo $ubidev | grep Name\: | awk '{print $2}'`
      if [ "$volname" == "$volume" ]; then
        mount -t ubifs $ubidev $dir -o bulk_read
        echo "MTD : Mounting of $ubidev on $dir done"
      fi
   done
}

#Mount RecoveryFS
fstype="UBI"
eval FindAndAttachUBI recoveryfs
eval FindAndMountUBI rootfs  /recoveryfs

cat /recoveryfs/etc/version > /sys/class/misc/telit_raw_data/smem_rfs_ver
#cat /recoveryfs/etc/version > /rfs_ver.txt
umount /recoveryfs
rmdir /recoveryfs
FindAndDetachUBI recoveryfs

cat /etc/version > /sys/class/misc/telit_raw_data/smem_fs_ver

exit