#  Unit test for the SPI driver.
#

. $TEST_ENV_SETUP

# Search the dev filesystem for the location of the device associated with the
# spidev
spi_module="spi_qsd"
spidev_module="spidev"
dev_location="/dev"
test="/usr/kernel-tests/spi/spi_test_telit"
spimod_location="/sys/bus/platform/drivers"

case `cat /sys/devices/soc0/build_id` in
	*9x07* )
		res="9607"
		busnum="4"
		chipselect="1"
		bufsiz="102400"
		modules_location="/usr/lib/modules/3.18.20/kernel/drivers/spi"
		;;
	*9x45* )
		res="9640";
		busnum="1"
		chipselect="1"
		bufsiz="102400"
		modules_location="/usr/lib/modules/3.10.49/kernel/drivers/spi"
		;;
	* )
		res="none"
		;;
esac
echo CHIPSET = $res

if [ -e $modules_location/$spidev_module".ko" ];then
	echo Module file exist.
	
	filescount=`lsmod $spidev_module* | awk 'END { print NR }'`  
	if [ $filescount -gt 0 ];then
		echo Remove previous loaded SPI module...
		rmmod $spidev_module
	fi
	
	insmod $modules_location/$spidev_module".ko" busnum=$busnum chipselect=$chipselect bufsiz=$bufsiz
	i=`echo $?`
	if [[ $i -ne 0 ]]; then
		echo "Failed to insert "$modules_location/$spidev_module ": $i"
		exit 1
	fi
	
	echo SPI module loaded.
	echo
	
	sleep 1
	
	filescount=`ls $dev_location/$spidev_module* | awk 'END { print NR }'`  
	if [ -z $filescount ];then
		echo SPI device not intialized.
		exit 1
	fi
else
	echo $modules_location/$spidev_module".ko" not exist.
	exit 1
fi

#Run Test
$test -d $busnum -c $chipselect -v -l
ret=`echo $?`

filescount=`lsmod $spidev_module* | awk 'END { print NR }'`  
if [ $filescount -gt 0 ];then
	echo
	echo Remove loaded SPI module...
	rmmod $spidev_module
fi

exit $ret

